==> zn-plugin-workflow-0.1.5.tgz: package/web/src/component/instance/BaseInfo.js <==
var React = require('react');

module.exports = React.createClass({
	getInitialState: function (){
		return {
			nextSchemaUUID: null,
			formItems: [
				{ title: '备注', name: 'zn_note', type: 'Textarea' },
				{ title: '附件', name: 'files', type: 'FileUploader' }
			]
		}
	},
	componentDidUpdate: function (prevProps, prevState){
		this.refs.form.reset();
	},
	__cancel: function (){
		zn.confirm('确定取消流程吗？', '提示', function (){
			zn.preloader.open({ title: '取消中...' });
			zn.http.post('/zn.plugin.workflow/wfinstance/cancel', {
				instanceId: this.props.base.id
			}).then(function (data){
				if(data.status==200){
					this.setState(data);
				}else {
					zn.toast.error(data.result);
				}
				zn.preloader.close();
			}.bind(this), function (){
				zn.toast.error('取消失败');
				zn.preloader.close();
			});
		}.bind(this));
	},
	__onCancel: function (){
		if(!this.state.nextSchemaUUID){
			return zn.notification.warning('流程已结束!'), false;
		}
		zn.confirm('驳回该流程吗？', '提示', function (){
			zn.preloader.open({ title: '提交中...' });
			zn.http.post('/zn.plugin.workflow/wfinstance/deny', {
				instanceId: this.props.base.id,
				options: value
			}).then(function (data){
				if(data.status==200){
					zn.toast.success('提交成功');
					this.state.nextSchemaUUID = null;
					this.props.onNextSuccess && this.props.onNextSuccess();
				}else {
					zn.toast.error(data.result);
				}
				zn.preloader.close();
			}.bind(this), function (){
				zn.toast.error('提交失败');
				zn.preloader.close();
			});
		}.bind(this));
		return false;
	},
	__onFormSubmitBefore: function (value) {
		if(!this.state.nextSchemaUUID){
			return zn.notification.warning('流程已结束!'), false;
		}
		if(this.refs.schema_form){
			var _temp = this.refs.schema_form.getValue();
			if(_temp){
				value.schema_form_data = JSON.stringify(_temp);
			}else {
				return zn.notification.warning('自定义表单还未填写完成!'), false;
			}
		}
		zn.confirm('确认该流程吗？', '提示', function (){
			zn.preloader.open({ title: '提交中...' });
			zn.http.post('/zn.plugin.workflow/wfinstance/next', {
				instanceId: this.props.base.id,
				nextSchemaUUID: this.state.nextSchemaUUID,
				options: value
			}).then(function (data){
				if(data.status==200){
					zn.toast.success('确认成功');
					this.state.nextSchemaUUID = null;
					this.props.onNextSuccess && this.props.onNextSuccess();
				}else {
					zn.toast.error(data.result);
				}
				zn.preloader.close();
			}.bind(this), function (){
				zn.toast.error('确认失败');
				zn.preloader.close();
			});
		}.bind(this));
		return false;
	},
	render:function(){
		var _next_ids = this.props.current.next_schemas.split(','),
			_next_texts = this.props.current.next_schemas_convert.split(',');
		return (
			<div className="zn-plugin-workflow-instance-base-info zn-plugin-workflow-panel" >
				<div className="title">
					<span>下一步(Next Step)</span>
					{this.props.base.isCreator && (this.props.base.state == 1 ? <zn.react.Button text="关闭" type="danger" />:<zn.react.Button text="打开" />)}
				</div>
				<div className="content">
					<ul className="next-steps">
						{
							_next_ids.map(function (value, index){
								if(!value){ return null; }
								if(!this.state.nextSchemaUUID){
									this.state.nextSchemaUUID = value;
								}
								return <li onClick={()=>this.setState({ nextSchemaUUID: value })} className={this.state.nextSchemaUUID==value?'selected':''}>{_next_texts[index]}</li>
							}.bind(this))
						}
					</ul>
					{
						(this.props.current.schema_fields && !!this.props.current.schema_fields.length) && <zn.react.Group title="自定义表单">
							<zn.react.Form
								ref="schema_form"
								valueKey="title"
								items={this.props.current.schema_fields}
								buttons={[]}/>
						</zn.react.Group>
					}
					{
						(this.props.base.state == 1 && this.state.nextSchemaUUID) && <zn.react.Group title="基础表单">
							<zn.react.Form
								ref="base_form"
								items={this.state.formItems}
								onSubmitBefore={this.__onFormSubmitBefore}
								buttons={[
									{ text: '拒绝(驳回)', icon: 'fa-microphone-slash', onClick: this.__onCancel, status: 'danger' },
									{ text: '确认通过', icon: 'fa-check-circle-o', type: 'submit', status: 'primary' }
								]} />
						</zn.react.Group>
					}
				</div>
			</div>
		);
	}
});

==> zn-plugin-workflow-0.1.14.tgz: package/web/src/component/instance/BaseInfo.js <==
var React = require('react');

module.exports = React.createClass({
	getInitialState: function (){
		return {
			nextSchemaUUID: null,
			formItems: [
				{ title: '备注', name: 'zn_note', type: 'Textarea' },
				{ title: '附件', name: 'files', type: 'FileUploader' }
			]
		}
	},
	componentDidUpdate: function (prevProps, prevState){
		this.refs.base_form.reset();
	},
	__cancel: function (){
		zn.confirm('确定取消流程吗？', '提示', function (){
			zn.preloader.open({ title: '取消中...' });
			zn.http.post('/zn.plugin.workflow/wfinstance/cancel', {
				instanceId: this.props.base.id
			}).then(function (data){
				if(data.status==200){
					this.setState(data);
				}else {
					zn.notification.error(data.result);
				}
				zn.preloader.close();
			}.bind(this), function (){
				zn.notification.error('取消失败');
				zn.preloader.close();
			});
		}.bind(this));
	},
	__onCancel: function (){
		if(!this.state.nextSchemaUUID){
			return zn.notification.warning('流程已结束!'), false;
		}
		if(this.refs.base_form){
			var _temp = this.refs.base_form.getValue();
			if(_temp){
				zn.confirm('驳回该流程吗？', '提示', function (){
					zn.preloader.open({ title: '提交中...' });
					zn.http.post('/zn.plugin.workflow/wfinstance/deny', {
						instanceId: this.props.base.id,
						options: _temp
					}).then(function (data){
						if(data.status==200){
							zn.notification.success('提交成功');
							this.state.nextSchemaUUID = null;
							this.props.onNextSuccess && this.props.onNextSuccess();
						}else {
							zn.notification.error(data.result);
						}
						zn.preloader.close();
					}.bind(this), function (){
						zn.notification.error('提交失败');
						zn.preloader.close();
					});
				}.bind(this));
			}else {
				return zn.notification.warning('表单还未填写完成!'), false;
			}
		}
		return false;
	},
	__onFormSubmitBefore: function (value) {
		if(!this.state.nextSchemaUUID){
			return zn.notification.warning('流程已结束!'), false;
		}
		if(this.refs.schema_form){
			var _temp = this.refs.schema_form.getValue();
			if(_temp){
				value.schema_form_data = JSON.stringify(_temp);
			}else {
				return zn.notification.warning('自定义表单还未填写完成!'), false;
			}
		}
		zn.confirm('确认该流程吗？', '提示', function (){
			zn.preloader.open({ title: '提交中...' });
			zn.http.post('/zn.plugin.workflow/wfinstance/next', {
				instanceId: this.props.base.id,
				nextSchemaUUID: this.state.nextSchemaUUID,
				options: value
			}).then(function (data){
				if(data.status==200){
					zn.notification.success('确认成功');
					this.state.nextSchemaUUID = null;
					this.props.onNextSuccess && this.props.onNextSuccess();
				}else {
					zn.notification.error(data.result);
				}
				zn.preloader.close();
			}.bind(this), function (){
				zn.notification.error('确认失败');
				zn.preloader.close();
			});
		}.bind(this));
		return false;
	},
	render:function(){
		var _next_ids = this.props.current.next_schemas.split(','),
			_next_texts = this.props.current.next_schemas_convert.split(',');
		if(!_next_ids.filter(function (id) {
			if(id){
				return true;
			}
		}).length){
			return null;
		}

		return (
			<div className="zn-plugin-workflow-instance-base-info zn-plugin-workflow-panel" >
				<div className="title">
					<span>下一步(Next Step)</span>
					{
						/*
							{this.props.base.isCreator && (this.props.base.state == 1 ? <zn.react.Button text="关闭" type="danger" />:<zn.react.Button text="打开" />)}
						*/
					}
				</div>
				<div className="content">
					<ul className="next-steps">
						{
							_next_ids.map(function (value, index){
								if(!value){ return null; }
								if(!this.state.nextSchemaUUID){
									this.state.nextSchemaUUID = value;
								}
								return <li onClick={()=>this.setState({ nextSchemaUUID: value })} className={this.state.nextSchemaUUID==value?'selected':''}>{_next_texts[index]}</li>
							}.bind(this))
						}
					</ul>
					{
						(this.props.current.schema_fields && !!this.props.current.schema_fields.length) && <zn.react.Group title="自定义表单">
							<zn.react.Form
								key={"wf_form_"+(new Date()).getTime()}
								ref="schema_form"
								valueKey="title"
								items={this.props.current.schema_fields}
								buttons={[]}/>
						</zn.react.Group>
					}
					{
						(this.props.base.closed == 0 && this.props.base.state == 1 && this.state.nextSchemaUUID) && <zn.react.Group title="基础表单">
							<zn.react.Form
								key={"wf_form_"+(new Date()).getTime()}
								ref="base_form"
								items={this.state.formItems}
								onSubmitBefore={this.__onFormSubmitBefore}
								buttons={[
									{ text: '拒绝(驳回)', icon: 'fa-microphone-slash', onClick: this.__onCancel, status: 'danger' },
									{ text: '确认通过', icon: 'fa-check-circle-o', type: 'submit', status: 'primary' }
								]} />
						</zn.react.Group>
					}
				</div>
			</div>
		);
	}
});
